From: "Krishnakumar. R" <krishnakumar@naturesoft.net>

A missing schedule_task -> schedule_work conversion.


 25-akpm/drivers/char/istallion.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff -puN drivers/char/istallion.c~istallion-build-fix drivers/char/istallion.c
--- 25/drivers/char/istallion.c~istallion-build-fix	Thu Sep 11 13:46:15 2003
+++ 25-akpm/drivers/char/istallion.c	Thu Sep 11 13:46:15 2003
@@ -2303,7 +2303,7 @@ static void stli_dohangup(void *arg)
 
 	/*
 	 * FIXME: There's a module removal race here: tty_hangup
 	 * calls schedule_task which will call into this
 	 * driver later.
 	 */
 	portp = (stliport_t *) arg;
@@ -2944,7 +2944,7 @@ static inline int stli_hostcmd(stlibrd_t
 			    ((portp->sigs & TIOCM_CD) == 0)) {
 				if (portp->flags & ASYNC_CHECK_CD) {
 					if (tty)
-						schedule_task(&portp->tqhangup);
+						schedule_work(&portp->tqhangup);
 				}
 			}
 		}
@@ -2303,7 +2303,7 @@ static void stli_dohangup(void *arg)
 	/*
 	 * FIXME: There's a module removal race here: tty_hangup
-	 * calls schedule_task which will call into this
+	 * calls schedule_work which will call into this
 	 * driver later.
 	 */

_